esp_efuse_get_field_size

Function esp_efuse_get_field_size 

pub unsafe extern "C" fn esp_efuse_get_field_size(
    field: *mut *const esp_efuse_desc_t,
) -> c_int
@brief Returns the number of bits used by field.

@param[in] field A pointer to the structure describing the fields of efuse.

@return Returns the number of bits used by field.