esp_eth_transmit_ctrl_vargs

Function esp_eth_transmit_ctrl_vargs 

pub unsafe extern "C" fn esp_eth_transmit_ctrl_vargs(
    hdl: esp_eth_handle_t,
    ctrl: *mut c_void,
    argc: u32,
    ...
) -> esp_err_t
@brief Extended Transmit with variable number of arguments

@note Typical intended use case of this function is to assemble Ethernet frame from multiple input buffers at lower layer of the driver (MAC layer) to avoid unnecessary buffer reallocation and copy.

@param hdl handle of Ethernet driver @param ctrl optional transmit control structure (MAC specific), set to NULL when not required @param argc number variable arguments @param … variable arguments @return - ESP_OK: transmit successful - ESP_ERR_INVALID_STATE: invalid driver state (e.i., driver is not started) - ESP_ERR_TIMEOUT: transmit frame buffer failed because HW was not get available in predefined period - ESP_FAIL: transmit frame buffer failed because some other error occurred