esp_http_client_add_auth

Function esp_http_client_add_auth 

pub unsafe extern "C" fn esp_http_client_add_auth(
    client: esp_http_client_handle_t,
) -> esp_err_t
@brief On receiving HTTP Status code 401, this API can be invoked to add authorization information.

@note There is a possibility of receiving body message with redirection status codes, thus make sure to flush off body data after calling this API.

@param[in] client The esp_http_client handle

@return - ESP_OK: Successfully added the authentication information. - ESP_ERR_INVALID_ARG: Invalid client handle passed. - ESP_ERR_NO_MEM: Memory allocation failed for the required fields. - ESP_ERR_NOT_SUPPORTED: Unsupported authentication type in the header. - ESP_FAIL: Failed to add authentication information due to other reasons.