esp_http_client_prepare

Function esp_http_client_prepare 

pub unsafe extern "C" fn esp_http_client_prepare(
    client: esp_http_client_handle_t,
) -> esp_err_t
@brief Prepare HTTP client for a new request This function initializes the client state and prepares authentication if needed. It should be called before sending a request.

@param[in] client The esp_http_client handle

@return

  • ESP_OK on successful
  • ESP_FAIL on error