esp_http_client_request_send

Function esp_http_client_request_send 

pub unsafe extern "C" fn esp_http_client_request_send(
    client: esp_http_client_handle_t,
    write_len: c_int,
) -> esp_err_t
@brief Send HTTP request headers and data This function sends the HTTP request line, headers, and any post data to the server.

@param[in] client The esp_http_client handle @param[in] write_len Length of data to write (for POST/PUT requests)

@return

  • ESP_OK on successful
  • ESP_FAIL on error
  • ESP_ERR_HTTP_WRITE_DATA if write operation fails