esp_image_bootloader_offset_get

Function esp_image_bootloader_offset_get 

pub unsafe extern "C" fn esp_image_bootloader_offset_get() -> u32
@brief Get the ota bootloader offset

The esp_image_verify functions use the offset to distinguish between application and bootloader verifications. The application must set the OTA bootloader offset before running any verification functions for the OTA bootloader partition.

@return ota Bootloader offset. UINT32_MAX - not set.