esp_int_wdt_cpu_init

Function esp_int_wdt_cpu_init 

pub unsafe extern "C" fn esp_int_wdt_cpu_init()
@brief Enable the interrupt watchdog on the current CPU.

This function is automatically called during application startup for each CPU that has enabled the interrupt watchdog in menuconfig.

@note esp_int_wdt_init() must be called first before calling this function