esp_libc_init

Function esp_libc_init 

pub unsafe extern "C" fn esp_libc_init()
Function which sets up newlib in ROM for use with ESP-IDF

Includes defining the syscall table, setting up any common locks, etc.

Called from the startup code, not intended to be called from application code.