esp_log_buffer_hex_internal

Function esp_log_buffer_hex_internal 

pub unsafe extern "C" fn esp_log_buffer_hex_internal(
    tag: *const c_char,
    buffer: *const c_void,
    buff_len: u16,
    level: esp_log_level_t,
)
@brief Logs a buffer of hexadecimal bytes at the specified log level.

This function logs a buffer of hexadecimal bytes with 16 bytes per line. The log level determines the severity of the log message.

@note This function does not check the log level against the ESP_LOCAL_LEVEL. The log level comparison should be done in esp_log.h.

@param tag Description tag to identify the log. @param buffer Pointer to the buffer array containing the data to be logged. @param buff_len Length of the buffer in bytes. @param level Log level indicating the severity of the log message.