esp_log_write

Function esp_log_write 

pub unsafe extern "C" fn esp_log_write(
    level: esp_log_level_t,
    tag: *const c_char,
    format: *const c_char,
    ...
)
@brief Write message into the log

This function is not intended to be used directly. Instead, use one of ESP_LOGE, ESP_LOGW, ESP_LOGI, ESP_LOGD, ESP_LOGV macros.

This function or these macros should not be used from an interrupt.

This function does not add any formatting elements such as color, timestamp, or tag. It checks the level and tag level. If logging is allowed then it outputs it as is.

@param level Log level of the message. @param tag It is used to check whether logging is enabled for that tag (depends on CONFIG_LOG_TAG_LEVEL_IMPL). @param format The format string for the log message. It has to be fully formatted, no additional formatting items will be added. @param … Optional arguments to be formatted according to the format string.