esp_netif_arp_get_client_by_mac

Function esp_netif_arp_get_client_by_mac 

pub unsafe extern "C" fn esp_netif_arp_get_client_by_mac(
    esp_netif: *mut esp_netif_t,
    mac_ip_pair: *mut esp_netif_pair_mac_ip_t,
) -> esp_err_t
@brief Populate IP addresses of client from the lwIP ARP cache on this interface

Walks the ARP table and fills in ip when the Ethernet address matches and the entry belongs to esp_netif.

@param[in] esp_netif Handle to esp-netif instance @param[in,out] mac_ip_pair MAC/IP pair to fill in the IP @return - ESP_OK on success (including when nothing was found in ARP) - ESP_ERR_ESP_NETIF_INVALID_PARAMS on invalid params - ESP_ERR_NOT_SUPPORTED if ARP is disabled in lwIP