esp_netif_free_rx_buffer

Function esp_netif_free_rx_buffer 

pub unsafe extern "C" fn esp_netif_free_rx_buffer(
    esp_netif: *mut c_void,
    buffer: *mut c_void,
)
@brief Free the rx buffer allocated by the media driver

This function gets called from network stack when the rx buffer to be freed in IO driver context, i.e. to deallocate a buffer owned by io driver (when data packets were passed to higher levels to avoid copying)

@param[in] esp_netif Handle to esp-netif instance @param[in] buffer Rx buffer pointer