esp_openthread_cli_init

Function esp_openthread_cli_init 

pub unsafe extern "C" fn esp_openthread_cli_init()
@brief This function initializes the OpenThread command line interface(CLI).

@note There are two ways to initialize the OpenThread CLI: 1. By creating a dedicated task via esp_openthread_cli_create_task

  2. By registering a console command with the ESP console via
     `esp_openthread_cli_console_command_register`
     If using this approach, the user must initialize the interface used
     by the console and also initialize esp_console manually. Additionally,
     the `host_connection_mode` should be set to `HOST_CONNECTION_MODE_NONE`.