pub unsafe extern "C" fn esp_openthread_rcp_send_command(
input: *const c_char,
)Expand description
@brief Sends a console command to RCP.
@param[in] input The pointer to a command string to be run on RCP.
pub unsafe extern "C" fn esp_openthread_rcp_send_command(
input: *const c_char,
)@brief Sends a console command to RCP.
@param[in] input The pointer to a command string to be run on RCP.