esp_ota_mark_app_invalid_rollback

Function esp_ota_mark_app_invalid_rollback 

pub unsafe extern "C" fn esp_ota_mark_app_invalid_rollback() -> esp_err_t
@brief This function is called to roll back to the previously workable app without reboot.

Checks applications on a flash drive that can be booted in case of rollback. If the flash does not have at least one app (except the running app) then rollback is not possible. @return

  • ESP_OK: if successful.
  • ESP_FAIL: if not successful.
  • ESP_ERR_OTA_ROLLBACK_FAILED: The rollback is not possible because the available OTA partitions on the flash do not contain a valid application.