esp_ota_mark_app_invalid_rollback_and_reboot

Function esp_ota_mark_app_invalid_rollback_and_reboot 

pub unsafe extern "C" fn esp_ota_mark_app_invalid_rollback_and_reboot() -> esp_err_t
@brief This function is called to roll back to the previously workable app with reboot.

Equivalent to calling esp_ota_mark_app_invalid_rollback(), and, if successful, followed by esp_restart().

@return

  • ESP_FAIL: if not successful.
  • ESP_ERR_OTA_ROLLBACK_FAILED: The rollback is not possible due to flash does not have any apps.