pub unsafe extern "C" fn esp_rom_output_to_channels(c: c_char)Expand description
@brief It outputs a character to different channels simultaneously. This function is used by esp_rom_printf/esp_rom_vprintf.
@param c Char to output.
pub unsafe extern "C" fn esp_rom_output_to_channels(c: c_char)@brief It outputs a character to different channels simultaneously. This function is used by esp_rom_printf/esp_rom_vprintf.
@param c Char to output.