esp_sleep_enable_timer_wakeup

Function esp_sleep_enable_timer_wakeup 

pub unsafe extern "C" fn esp_sleep_enable_timer_wakeup(
    time_in_us: u64,
) -> esp_err_t
@brief Enable wakeup by timer @param time_in_us time before wakeup, in microseconds @note The valid time_in_us value depends on the bit width of the lp_timer/rtc_timer counter and the current slow clock source selection (Refer RTC clock source configuration in menuconfig). Valid values should be positive values less than RTC slow clock period * (2 ^ RTC timer bitwidth).

@return - ESP_OK on success - ESP_ERR_INVALID_ARG if value is out of range.