pub unsafe extern "C" fn esp_wifi_get_protocol(
ifx: wifi_interface_t,
protocol_bitmap: *mut u8,
) -> esp_err_tExpand description
@brief Get the current protocol bitmap of the specified interface
@attention 1. When WiFi band mode is 2.4G only, it will return the protocol supported in the 2.4G band @attention 2. When WiFi band mode is 5G only, it will return the protocol supported in the 5G band @attention 3. Can not get WiFi protocol under band mode 2.4G + 5G (WIFI_BAND_MODE_AUTO), you can use esp_wifi_get_protocols instead @attention 4. API return ESP_ERR_NOT_SUPPORTED if the band mode is set to 2.4G + 5G (WIFI_BAND_MODE_AUTO)
@param ifx interface @param[out] protocol_bitmap store current WiFi protocol bitmap of interface ifx
@return
- ESP_OK: succeed
- ESP_ERR_WIFI_NOT_INIT: WiFi is not initialized by esp_wifi_init
- ESP_ERR_WIFI_IF: invalid interface
- ESP_ERR_INVALID_ARG: invalid argument
- ESP_ERR_NOT_SUPPORTED: This API is not supported when the band mode is set to 2.4G + 5G (WIFI_BAND_MODE_AUTO)
- others: refer to error codes in esp_err.h