pub unsafe extern "C" fn heap_caps_get_containing_block_size(
ptr: *mut c_void,
) -> usizeExpand description
@brief Return the size of the block containing the pointer passed as parameter.
@param ptr Pointer to currently allocated heap memory. The pointer value must be within the allocated memory and the memory must not be freed.
@note The app will crash with an assertion failure if the pointer is invalid.
@return Size of the containing block allocated.