pub unsafe extern "C" fn i2s_channel_tune_rate(
handle: i2s_chan_handle_t,
tune_cfg: *const i2s_tuning_config_t,
tune_info: *mut i2s_tuning_info_t,
) -> esp_err_tExpand description
@brief Tune the I2S clock rate @note Only allowed to be called when the channel state is READY, (i.e., channel has been initialized, but not started) @note This function is mainly to fine-tuning the mclk to match the speed of producer and consumer. So that to avoid exsaust of the memory to store the data from producer. Please take care the how different the frequency error can be tolerant by your codec, otherwise the codec might stop working if the frequency changes a lot.
@param[in] handle I2S channel handler @param[in] tune_cfg The clock tuning configuration, can be NULL if only need the current clock result @param[out] tune_info The clock tuning information, can be NULL if not needed @return - ESP_OK Tune the clock successfully - ESP_ERR_INVALID_ARG Tune the clock failed because of the invalid argument like NULL pointer or out of range - ESP_ERR_NOT_SUPPORTED Tune the clock failed because this function does not support to tune the external clock source