is_openthread_internal_mesh_local_addr

Function is_openthread_internal_mesh_local_addr 

pub unsafe extern "C" fn is_openthread_internal_mesh_local_addr(
    address: *const otIp6Address,
) -> bool
@brief This function judges the target address is openthread mesh local or not.

@param[in] address The address.

@return - True if the address is openthread mesh local, otherwise false