pub unsafe extern "C" fn mbedtls_asn1_store_named_data(
list: *mut *mut mbedtls_asn1_named_data,
oid: *const c_char,
oid_len: usize,
val: *const c_uchar,
val_len: usize,
) -> *mut mbedtls_asn1_named_dataExpand description
\brief Create or find a specific named_data entry for writing in a sequence or list based on the OID. If not already in there, a new entry is added to the head of the list. Warning: Destructive behaviour for the val data!
\param list The pointer to the location of the head of the list to seek through (will be updated in case of a new entry). \param oid The OID to look for. \param oid_len The size of the OID. \param val The associated data to store. If this is \c NULL, no data is copied to the new or existing buffer. \param val_len The minimum length of the data buffer needed. If this is 0, do not allocate a buffer for the associated data. If the OID was already present, enlarge, shrink or free the existing buffer to fit \p val_len.
\return A pointer to the new / existing entry on success. \return \c NULL if there was a memory allocation error.