mbedtls_asn1_write_bitstring

Function mbedtls_asn1_write_bitstring 

pub unsafe extern "C" fn mbedtls_asn1_write_bitstring(
    p: *mut *mut c_uchar,
    start: *const c_uchar,
    buf: *const c_uchar,
    bits: usize,
) -> c_int
\brief Write a bitstring tag (#MBEDTLS_ASN1_BIT_STRING) and value in ASN.1 format.

\note This function works backwards in data buffer.

\param p The reference to the current position pointer. \param start The start of the buffer, for bounds-checking. \param buf The bitstring to write. \param bits The total number of bits in the bitstring.

\return The number of bytes written to \p p on success. \return A negative error code on failure.