mbedtls_asn1_write_enum

Function mbedtls_asn1_write_enum 

pub unsafe extern "C" fn mbedtls_asn1_write_enum(
    p: *mut *mut c_uchar,
    start: *const c_uchar,
    val: c_int,
) -> c_int
\brief Write an enum tag (#MBEDTLS_ASN1_ENUMERATED) and value in ASN.1 format.

\note This function works backwards in data buffer.

\param p The reference to the current position pointer. \param start The start of the buffer, for bounds-checking. \param val The integer value to write.

\return The number of bytes written to \p p on success. \return A negative \c MBEDTLS_ERR_ASN1_XXX error code on failure.