mbedtls_asn1_write_len

Function mbedtls_asn1_write_len 

pub unsafe extern "C" fn mbedtls_asn1_write_len(
    p: *mut *mut c_uchar,
    start: *const c_uchar,
    len: usize,
) -> c_int
\brief Write a length field in ASN.1 format.

\note This function works backwards in data buffer.

\param p The reference to the current position pointer. \param start The start of the buffer, for bounds-checking. \param len The length value to write.

\return The number of bytes written to \p p on success. \return A negative \c MBEDTLS_ERR_ASN1_XXX error code on failure.