mbedtls_asn1_write_mpi

Function mbedtls_asn1_write_mpi 

pub unsafe extern "C" fn mbedtls_asn1_write_mpi(
    p: *mut *mut c_uchar,
    start: *const c_uchar,
    X: *const mbedtls_mpi,
) -> c_int
\brief Write an arbitrary-precision number (#MBEDTLS_ASN1_INTEGER) in ASN.1 format.

\note This function works backwards in data buffer.

\param p The reference to the current position pointer. \param start The start of the buffer, for bounds-checking. \param X The MPI to write. It must be non-negative.

\return The number of bytes written to \p p on success. \return A negative \c MBEDTLS_ERR_ASN1_XXX error code on failure.