pub unsafe extern "C" fn mbedtls_asn1_write_null(
p: *mut *mut c_uchar,
start: *const c_uchar,
) -> c_intExpand description
\brief Write a NULL tag (#MBEDTLS_ASN1_NULL) with zero data in ASN.1 format.
\note This function works backwards in data buffer.
\param p The reference to the current position pointer. \param start The start of the buffer, for bounds-checking.
\return The number of bytes written to \p p on success. \return A negative \c MBEDTLS_ERR_ASN1_XXX error code on failure.