mbedtls_asn1_write_octet_string

Function mbedtls_asn1_write_octet_string 

pub unsafe extern "C" fn mbedtls_asn1_write_octet_string(
    p: *mut *mut c_uchar,
    start: *const c_uchar,
    buf: *const c_uchar,
    size: usize,
) -> c_int
\brief Write an octet string tag (#MBEDTLS_ASN1_OCTET_STRING) and value in ASN.1 format.

\note This function works backwards in data buffer.

\param p The reference to the current position pointer. \param start The start of the buffer, for bounds-checking. \param buf The buffer holding the data to write. \param size The length of the data buffer \p buf.

\return The number of bytes written to \p p on success. \return A negative error code on failure.