mbedtls_asn1_write_oid

Function mbedtls_asn1_write_oid 

pub unsafe extern "C" fn mbedtls_asn1_write_oid(
    p: *mut *mut c_uchar,
    start: *const c_uchar,
    oid: *const c_char,
    oid_len: usize,
) -> c_int
\brief Write an OID tag (#MBEDTLS_ASN1_OID) and data in ASN.1 format.

\note This function works backwards in data buffer.

\param p The reference to the current position pointer. \param start The start of the buffer, for bounds-checking. \param oid The OID to write. \param oid_len The length of the OID.

\return The number of bytes written to \p p on success. \return A negative \c MBEDTLS_ERR_ASN1_XXX error code on failure.