mbedtls_asn1_write_tag

Function mbedtls_asn1_write_tag 

pub unsafe extern "C" fn mbedtls_asn1_write_tag(
    p: *mut *mut c_uchar,
    start: *const c_uchar,
    tag: c_uchar,
) -> c_int
\brief Write an ASN.1 tag in ASN.1 format.

\note This function works backwards in data buffer.

\param p The reference to the current position pointer. \param start The start of the buffer, for bounds-checking. \param tag The tag to write.

\return The number of bytes written to \p p on success. \return A negative \c MBEDTLS_ERR_ASN1_XXX error code on failure.