mbedtls_dhm_free

Function mbedtls_dhm_free 

pub unsafe extern "C" fn mbedtls_dhm_free(
    ctx: *mut mbedtls_dhm_context,
)
\brief This function frees and clears the components of a DHM context.

\param ctx The DHM context to free and clear. This may be \c NULL, in which case this function is a no-op. If it is not \c NULL, it must point to an initialized DHM context.