mbedtls_dhm_get_bitlen

Function mbedtls_dhm_get_bitlen 

pub unsafe extern "C" fn mbedtls_dhm_get_bitlen(
    ctx: *const mbedtls_dhm_context,
) -> usize
\brief This function returns the size of the prime modulus in bits.

\param ctx The DHM context to query.

\return The size of the prime modulus in bits, i.e. the number n such that 2^(n-1) <= P < 2^n.