mbedtls_dhm_parse_dhm

Function mbedtls_dhm_parse_dhm 

pub unsafe extern "C" fn mbedtls_dhm_parse_dhm(
    dhm: *mut mbedtls_dhm_context,
    dhmin: *const c_uchar,
    dhminlen: usize,
) -> c_int
\brief This function parses DHM parameters in PEM or DER format.

\param dhm The DHM context to import the DHM parameters into. This must be initialized. \param dhmin The input buffer. This must be a readable buffer of length \p dhminlen Bytes. \param dhminlen The size of the input buffer \p dhmin, including the terminating \c NULL Byte for PEM data.

\return \c 0 on success. \return An \c MBEDTLS_ERR_DHM_XXX or \c MBEDTLS_ERR_PEM_XXX error code on failure.