pub unsafe extern "C" fn mbedtls_dhm_read_params(
ctx: *mut mbedtls_dhm_context,
p: *mut *mut c_uchar,
end: *const c_uchar,
) -> c_intExpand description
\brief This function parses the DHM parameters in a TLS ServerKeyExchange handshake message (DHM modulus, generator, and public key).
\note In a TLS handshake, this is the how the client sets up its DHM context from the server’s public DHM key material.
\param ctx The DHM context to use. This must be initialized. \param p On input, *p must be the start of the input buffer. On output, *p is updated to point to the end of the data that has been read. On success, this is the first byte past the end of the ServerKeyExchange parameters. On error, this is the point at which an error has been detected, which is usually not useful except to debug failures. \param end The end of the input buffer.
\return \c 0 on success. \return An \c MBEDTLS_ERR_DHM_XXX error code on failure.