mbedtls_dhm_set_group

Function mbedtls_dhm_set_group 

pub unsafe extern "C" fn mbedtls_dhm_set_group(
    ctx: *mut mbedtls_dhm_context,
    P: *const mbedtls_mpi,
    G: *const mbedtls_mpi,
) -> c_int
\brief This function sets the prime modulus and generator.

\note This function can be used to set \c ctx->P, \c ctx->G in preparation for mbedtls_dhm_make_params().

\param ctx The DHM context to configure. This must be initialized. \param P The MPI holding the DHM prime modulus. This must be an initialized MPI. \param G The MPI holding the DHM generator. This must be an initialized MPI.

\return \c 0 if successful. \return An \c MBEDTLS_ERR_DHM_XXX error code on failure.