pub unsafe extern "C" fn mbedtls_hkdf_expand(
md: *const mbedtls_md_info_t,
prk: *const c_uchar,
prk_len: usize,
info: *const c_uchar,
info_len: usize,
okm: *mut c_uchar,
okm_len: usize,
) -> c_intExpand description
\brief Expand the supplied \p prk into several additional pseudorandom keys, which is the output of the HKDF.
\warning This function should only be used if the security of it has been studied and established in that particular context (eg. TLS 1.3 key schedule). For standard HKDF security guarantees use \c mbedtls_hkdf instead.
\param md A hash function; md.size denotes the length of the hash function output in bytes. \param prk A pseudorandom key of at least md.size bytes. \p prk is usually the output from the HKDF extract step. \param prk_len The length in bytes of \p prk. \param info An optional context and application specific information string. This can be a zero-length string. \param info_len The length of \p info in bytes. \param okm The output keying material of \p okm_len bytes. \param okm_len The length of the output keying material in bytes. This must be less than or equal to 255 * md.size bytes.
\return 0 on success. \return #MBEDTLS_ERR_HKDF_BAD_INPUT_DATA when the parameters are invalid. \return An MBEDTLS_ERR_MD_* error for errors returned from the underlying MD layer.