pub unsafe extern "C" fn mbedtls_hmac_drbg_reseed(
ctx: *mut mbedtls_hmac_drbg_context,
additional: *const c_uchar,
len: usize,
) -> c_intExpand description
\brief This function reseeds the HMAC_DRBG context, that is extracts data from the entropy source.
\note This function is not thread-safe. It is not safe to call this function if another thread might be concurrently obtaining random numbers from the same context or updating or reseeding the same context.
\param ctx The HMAC_DRBG context. \param additional Additional data to add to the state. If this is \c NULL, there is no additional data and \p len should be \c 0. \param len The length of the additional data. This must be at most #MBEDTLS_HMAC_DRBG_MAX_INPUT and also at most #MBEDTLS_HMAC_DRBG_MAX_SEED_INPUT - \c entropy_len where \c entropy_len is the entropy length (see mbedtls_hmac_drbg_set_entropy_len()).
\return \c 0 if successful. \return #MBEDTLS_ERR_HMAC_DRBG_ENTROPY_SOURCE_FAILED if a call to the entropy function failed.