pub unsafe extern "C" fn mbedtls_hmac_drbg_seed(
ctx: *mut mbedtls_hmac_drbg_context,
md_info: *const mbedtls_md_info_t,
f_entropy: Option<unsafe extern "C" fn(arg1: *mut c_void, arg2: *mut c_uchar, arg3: usize) -> c_int>,
p_entropy: *mut c_void,
custom: *const c_uchar,
len: usize,
) -> c_intExpand description
\param ctx HMAC_DRBG context to be seeded. \param md_info MD algorithm to use for HMAC_DRBG. \param f_entropy The entropy callback, taking as arguments the \p p_entropy context, the buffer to fill, and the length of the buffer. \p f_entropy is always called with a length that is less than or equal to the entropy length. \param p_entropy The entropy context to pass to \p f_entropy. \param custom The personalization string. This can be \c NULL, in which case the personalization string is empty regardless of the value of \p len. \param len The length of the personalization string. This must be at most #MBEDTLS_HMAC_DRBG_MAX_INPUT and also at most #MBEDTLS_HMAC_DRBG_MAX_SEED_INPUT - \c entropy_len * 3 / 2 where \c entropy_len is the entropy length described above.
\return \c 0 if successful. \return #MBEDTLS_ERR_MD_BAD_INPUT_DATA if \p md_info is invalid. \return #MBEDTLS_ERR_MD_ALLOC_FAILED if there was not enough memory to allocate context data. \return #MBEDTLS_ERR_HMAC_DRBG_ENTROPY_SOURCE_FAILED if the call to \p f_entropy failed.