mbedtls_hmac_drbg_set_prediction_resistance

Function mbedtls_hmac_drbg_set_prediction_resistance 

pub unsafe extern "C" fn mbedtls_hmac_drbg_set_prediction_resistance(
    ctx: *mut mbedtls_hmac_drbg_context,
    resistance: c_int,
)
\brief This function turns prediction resistance on or off. The default value is off.

\note If enabled, entropy is gathered at the beginning of every call to mbedtls_hmac_drbg_random_with_add() or mbedtls_hmac_drbg_random(). Only use this if your entropy source has sufficient throughput.

\param ctx The HMAC_DRBG context. \param resistance #MBEDTLS_HMAC_DRBG_PR_ON or #MBEDTLS_HMAC_DRBG_PR_OFF.