mbedtls_hmac_drbg_update

Function mbedtls_hmac_drbg_update 

pub unsafe extern "C" fn mbedtls_hmac_drbg_update(
    ctx: *mut mbedtls_hmac_drbg_context,
    additional: *const c_uchar,
    add_len: usize,
) -> c_int
\brief This function updates the state of the HMAC_DRBG context.

\note This function is not thread-safe. It is not safe to call this function if another thread might be concurrently obtaining random numbers from the same context or updating or reseeding the same context.

\param ctx The HMAC_DRBG context. \param additional The data to update the state with. If this is \c NULL, there is no additional data. \param add_len Length of \p additional in bytes. Unused if \p additional is \c NULL.

\return \c 0 on success, or an error from the underlying hash calculation.