pub unsafe extern "C" fn mbedtls_lms_import_public_key(
ctx: *mut mbedtls_lms_public_t,
key: *const c_uchar,
key_size: usize,
) -> c_intExpand description
\brief This function imports an LMS public key into a public LMS context.
\note Before this function is called, the context must have been initialized.
\note See IETF RFC8554 for details of the encoding of this public key.
\param ctx The initialized LMS context store the key in. \param key The buffer from which the key will be read. #MBEDTLS_LMS_PUBLIC_KEY_LEN bytes will be read from this. \param key_size The size of the key being imported.
\return \c 0 on success. \return A non-zero error code on failure.