mbedtls_lms_verify

Function mbedtls_lms_verify 

pub unsafe extern "C" fn mbedtls_lms_verify(
    ctx: *const mbedtls_lms_public_t,
    msg: *const c_uchar,
    msg_size: usize,
    sig: *const c_uchar,
    sig_size: usize,
) -> c_int
\brief This function verifies a LMS signature, using a LMS context that contains a public key.

\note Before this function is called, the context must have been initialized and must contain a public key (either by import or generation).

\param ctx The initialized LMS public context from which the public key will be read. \param msg The buffer from which the message will be read. \param msg_size The size of the message that will be read. \param sig The buf from which the signature will be read. #MBEDTLS_LMS_SIG_LEN bytes will be read from this. \param sig_size The size of the signature to be verified.

\return \c 0 on successful verification. \return A non-zero error code on failure.