mbedtls_nist_kw_init

Function mbedtls_nist_kw_init 

pub unsafe extern "C" fn mbedtls_nist_kw_init(
    ctx: *mut mbedtls_nist_kw_context,
)
\brief This function initializes the specified key wrapping context to make references valid and prepare the context for mbedtls_nist_kw_setkey() or mbedtls_nist_kw_free().

\param ctx The key wrapping context to initialize.