pub unsafe extern "C" fn mbedtls_nist_kw_setkey(
ctx: *mut mbedtls_nist_kw_context,
cipher: mbedtls_cipher_id_t,
key: *const c_uchar,
keybits: c_uint,
is_wrap: c_int,
) -> c_intExpand description
\brief This function initializes the key wrapping context set in the \p ctx parameter and sets the encryption key.
\param ctx The key wrapping context. \param cipher The 128-bit block cipher to use. Only AES is supported. \param key The Key Encryption Key (KEK). \param keybits The KEK size in bits. This must be acceptable by the cipher. \param is_wrap Specify whether the operation within the context is wrapping or unwrapping
\return \c 0 on success. \return \c MBEDTLS_ERR_CIPHER_BAD_INPUT_DATA for any invalid input. \return \c MBEDTLS_ERR_CIPHER_FEATURE_UNAVAILABLE for 128-bit block ciphers which are not supported. \return cipher-specific error code on failure of the underlying cipher.