mbedtls_pkcs5_pbkdf2_hmac_ext

Function mbedtls_pkcs5_pbkdf2_hmac_ext 

pub unsafe extern "C" fn mbedtls_pkcs5_pbkdf2_hmac_ext(
    md_type: mbedtls_md_type_t,
    password: *const c_uchar,
    plen: usize,
    salt: *const c_uchar,
    slen: usize,
    iteration_count: c_uint,
    key_length: u32,
    output: *mut c_uchar,
) -> c_int
\brief PKCS#5 PBKDF2 using HMAC without using the HMAC context

\param md_type Hash algorithm used \param password Password to use when generating key \param plen Length of password \param salt Salt to use when generating key \param slen Length of salt \param iteration_count Iteration count \param key_length Length of generated key in bytes \param output Generated key. Must be at least as big as key_length

\returns 0 on success, or a MBEDTLS_ERR_XXX code if verification fails.