pub unsafe extern "C" fn mbedtls_pkcs7_parse_der(
pkcs7: *mut mbedtls_pkcs7,
buf: *const c_uchar,
buflen: usize,
) -> c_intExpand description
\brief Parse a single DER formatted PKCS #7 detached signature.
\param pkcs7 The mbedtls_pkcs7 structure to be filled by the parser. \param buf The buffer holding only the DER encoded PKCS #7 content. \param buflen The size in bytes of \p buf. The size must be exactly the length of the DER encoded PKCS #7 content.
\note This function makes an internal copy of the PKCS #7 buffer \p buf. In particular, \p buf may be destroyed or reused after this call returns. \note Signatures with internal data are not supported.
\return The \c mbedtls_pkcs7_type of \p buf, if successful. \return A negative error code on failure.