mbedtls_platform_setup

Function mbedtls_platform_setup 

pub unsafe extern "C" fn mbedtls_platform_setup(
    ctx: *mut mbedtls_platform_context,
) -> c_int
\brief This function performs any platform-specific initialization operations.

\note This function should be called before any other library functions.

     Its implementation is platform-specific, and unless
     platform-specific code is provided, it does nothing.

\note The usage and necessity of this function is dependent on the platform.

\param ctx The platform context.

\return \c 0 on success.