mbedtls_platform_teardown

Function mbedtls_platform_teardown 

pub unsafe extern "C" fn mbedtls_platform_teardown(
    ctx: *mut mbedtls_platform_context,
)
\brief This function performs any platform teardown operations.

\note This function should be called after every other Mbed TLS module has been correctly freed using the appropriate free function.

     Its implementation is platform-specific, and unless
     platform-specific code is provided, it does nothing.

\note The usage and necessity of this function is dependent on the platform.

\param ctx The platform context.