pub unsafe extern "C" fn mbedtls_ssl_cache_free(
cache: *mut mbedtls_ssl_cache_context,
)Expand description
\brief Free referenced items in a cache context and clear memory
\param cache SSL cache context
pub unsafe extern "C" fn mbedtls_ssl_cache_free(
cache: *mut mbedtls_ssl_cache_context,
)\brief Free referenced items in a cache context and clear memory
\param cache SSL cache context