pub unsafe extern "C" fn mbedtls_ssl_cache_get(
data: *mut c_void,
session_id: *const c_uchar,
session_id_len: usize,
session: *mut mbedtls_ssl_session,
) -> c_intExpand description
\brief Cache get callback implementation (Thread-safe if MBEDTLS_THREADING_C is enabled)
\param data The SSL cache context to use. \param session_id The pointer to the buffer holding the session ID for the session to load. \param session_id_len The length of \p session_id in bytes. \param session The address at which to store the session associated with \p session_id, if present.
\return \c 0 on success. \return #MBEDTLS_ERR_SSL_CACHE_ENTRY_NOT_FOUND if there is no cache entry with specified session ID found, or any other negative error code for other failures.