mbedtls_ssl_cache_remove

Function mbedtls_ssl_cache_remove 

pub unsafe extern "C" fn mbedtls_ssl_cache_remove(
    data: *mut c_void,
    session_id: *const c_uchar,
    session_id_len: usize,
) -> c_int
\brief Remove the cache entry by the session ID (Thread-safe if MBEDTLS_THREADING_C is enabled)

\param data The SSL cache context to use. \param session_id The pointer to the buffer holding the session ID associated to session. \param session_id_len The length of \p session_id in bytes.

\return \c 0 on success. This indicates the cache entry for the session with provided ID is removed or does not exist. \return A negative error code on failure.