pub unsafe extern "C" fn mbedtls_version_get_string(
string: *mut c_char,
)Expand description
Get the version string (“x.y.z”).
\param string The string that will receive the value. (Should be at least 9 bytes in size)
pub unsafe extern "C" fn mbedtls_version_get_string(
string: *mut c_char,
)Get the version string (“x.y.z”).
\param string The string that will receive the value. (Should be at least 9 bytes in size)