mbedtls_x509_csr_parse_der

Function mbedtls_x509_csr_parse_der 

pub unsafe extern "C" fn mbedtls_x509_csr_parse_der(
    csr: *mut mbedtls_x509_csr,
    buf: *const c_uchar,
    buflen: usize,
) -> c_int
\brief Load a Certificate Signing Request (CSR) in DER format

\note Any unsupported requested extensions are silently ignored, unless the critical flag is set, in which case the CSR is rejected.

\note If #MBEDTLS_USE_PSA_CRYPTO is enabled, the PSA crypto subsystem must have been initialized by calling psa_crypto_init() before calling this function.

\param csr CSR context to fill \param buf buffer holding the CRL data \param buflen size of the buffer

\return 0 if successful, or a specific X509 error code