mbedtls_x509_csr_parse_der_with_ext_cb

Function mbedtls_x509_csr_parse_der_with_ext_cb 

pub unsafe extern "C" fn mbedtls_x509_csr_parse_der_with_ext_cb(
    csr: *mut mbedtls_x509_csr,
    buf: *const c_uchar,
    buflen: usize,
    cb: mbedtls_x509_csr_ext_cb_t,
    p_ctx: *mut c_void,
) -> c_int
\brief Load a Certificate Signing Request (CSR) in DER format

\note Any unsupported requested extensions are silently ignored, unless the critical flag is set, in which case the result of the callback function decides whether CSR is rejected.

\note If #MBEDTLS_USE_PSA_CRYPTO is enabled, the PSA crypto subsystem must have been initialized by calling psa_crypto_init() before calling this function.

\param csr CSR context to fill \param buf buffer holding the CRL data \param buflen size of the buffer \param cb A callback invoked for every unsupported certificate extension. \param p_ctx An opaque context passed to the callback.

\return 0 if successful, or a specific X509 error code