phy_module_disable

Function phy_module_disable 

pub unsafe extern "C" fn phy_module_disable()
@brief Disable phy module by gating related clock and asserting the reset signal.

@note This function releases clocks required during the PHY enable sequence.