pub unsafe extern "C" fn phy_module_enable()Expand description
@brief Enable phy module by un-gating related clock and de-asserting the reset signal.
@note This function acquires clocks required during the PHY enable sequence.
pub unsafe extern "C" fn phy_module_enable()@brief Enable phy module by un-gating related clock and de-asserting the reset signal.
@note This function acquires clocks required during the PHY enable sequence.