pub unsafe extern "C" fn phy_module_has_clock_bits(mask: u32) -> boolExpand description
@brief Checks whether phy module has all bits in @p mask set.
@return true if all bits in @p mask are set; false otherwise.
pub unsafe extern "C" fn phy_module_has_clock_bits(mask: u32) -> bool@brief Checks whether phy module has all bits in @p mask set.
@return true if all bits in @p mask are set; false otherwise.