rv_utils_dbgr_is_attached

Function rv_utils_dbgr_is_attached 

pub unsafe extern "C" fn rv_utils_dbgr_is_attached() -> bool
To use hal function for compatibility meanwhile keep hal dependency private, this function is implemented in rv_utils.c