spi_slave_enable

Function spi_slave_enable 

pub unsafe extern "C" fn spi_slave_enable(
    host: spi_host_device_t,
) -> esp_err_t
@brief Enable the spi slave function for an initialized spi host @note No need to call this function additionally after spi_slave_initialize, because it has been enabled already during the initialization.

@param host SPI peripheral to be enabled @return - ESP_OK On success - ESP_ERR_INVALID_ARG Unsupported host - ESP_ERR_INVALID_STATE Peripheral already enabled