uart_detect_bitrate_stop

Function uart_detect_bitrate_stop 

pub unsafe extern "C" fn uart_detect_bitrate_stop(
    uart_num: uart_port_t,
    deinit: bool,
    ret_res: *mut uart_bitrate_res_t,
) -> esp_err_t
@brief Stop the bitrate detection

The measurement period should last for at least one-byte long if detecting UART baud rate, then call this function to stop and get the measurement result.

@param uart_num The ID of the UART port @param deinit Whether to release the UART port after finishing the measurement @param[out] ret_res Structure to store the measurement results @return - ESP_OK on success - ESP_ERR_INVALID_ARG Parameter error - ESP_FAIL Unknown tick frequency