wifi_prov_mgr_is_sm_idle

Function wifi_prov_mgr_is_sm_idle 

pub unsafe extern "C" fn wifi_prov_mgr_is_sm_idle() -> bool
@brief Checks whether the provisioning state machine is idle

@return True if state machine is idle, else false