i2s_pdm_rx_slot_config_t

Struct i2s_pdm_rx_slot_config_t 

#[repr(C)]
pub struct i2s_pdm_rx_slot_config_t { pub data_bit_width: i2s_data_bit_width_t, pub slot_bit_width: i2s_slot_bit_width_t, pub slot_mode: i2s_slot_mode_t, pub slot_mask: i2s_pdm_slot_mask_t, pub data_fmt: i2s_pdm_data_fmt_t, }
@brief I2S slot configuration for PDM RX mode

Fields

data_bit_width: i2s_data_bit_width_t

< I2S sample data bit width (valid data bits per sample), only support 16 bits for PDM mode

slot_bit_width: i2s_slot_bit_width_t

< I2S slot bit width (total bits per slot) , only support 16 bits for PDM mode

slot_mode: i2s_slot_mode_t

< Set mono or stereo mode with I2S_SLOT_MODE_MONO or I2S_SLOT_MODE_STEREO

slot_mask: i2s_pdm_slot_mask_t

< Choose the slots to activate

data_fmt: i2s_pdm_data_fmt_t

< The data format of PDM RX mode. It determines what kind of data format is read in software. Typically, set this field to I2S_PDM_DATA_FMT_PCM when PCM2PDM filter is supported in the hardware, so that the hardware PDM2PCM filter will help to convert the raw PDM data on the line into PCM format, And then you can read PCM format data in software. Otherwise if this field is set to I2S_PDM_DATA_FMT_RAW, The data read in software are still in raw PDM format, you may need to convert the raw PDM data into PCM format manually by a software filter.