#[repr(C)]pub struct i2s_tuning_config_t {
pub tune_mode: i2s_tuning_mode_t,
pub tune_mclk_val: i32,
pub max_delta_mclk: i32,
pub min_delta_mclk: i32,
}Expand description
@brief I2S clock tuning configurations
Fields
tune_mode: i2s_tuning_mode_t< Tuning mode, which decides how to tune the MCLK with the tuning value
tune_mclk_val: i32< Tuning value
max_delta_mclk: i32< The maximum frequency that can be increased comparing to the initial MCLK freuqnecy
min_delta_mclk: i32< The minimum frequency that can be decreased comparing to the initial MCLK freuqnecy