mbedtls_lmots_parameters_t

Struct mbedtls_lmots_parameters_t 

#[repr(C)]
pub struct mbedtls_lmots_parameters_t { pub private_I_key_identifier: [c_uchar; 16], pub private_q_leaf_identifier: [c_uchar; 4], pub private_type: mbedtls_lmots_algorithm_type_t, }
LMOTS parameters structure.

This contains the metadata associated with an LMOTS key, detailing the algorithm type, the key ID, and the leaf identifier should be key be part of a LMS key.

Fields

private_I_key_identifier: [c_uchar; 16]

< The key identifier.

private_q_leaf_identifier: [c_uchar; 4]

< Which leaf of the LMS key this is. 0 if the key is not part of an LMS key.

private_type: mbedtls_lmots_algorithm_type_t

< The LM-OTS key type identifier as per IANA. Only SHA256_N32_W8 is currently supported.