#[repr(C)]pub struct mbedtls_lmots_public_t {
pub private_params: mbedtls_lmots_parameters_t,
pub private_public_key: [c_uchar; 32],
pub private_have_public_key: c_uchar,
}Expand description
LMOTS public context structure.
A LMOTS public key is a hash output, and the applicable parameter set.
The context must be initialized before it is used. A public key must either be imported or generated from a private context.
\dot digraph lmots_public_t { UNINITIALIZED -> INIT [label=“init”]; HAVE_PUBLIC_KEY -> INIT [label=“free”]; INIT -> HAVE_PUBLIC_KEY [label=“import_public_key”]; INIT -> HAVE_PUBLIC_KEY [label=“calculate_public_key from private key”]; HAVE_PUBLIC_KEY -> HAVE_PUBLIC_KEY [label=“export_public_key”]; } \enddot
Fields
private_params: mbedtls_lmots_parameters_tprivate_public_key: [c_uchar; 32]private_have_public_key: c_uchar< Whether the context contains a public key. Boolean values only.