mbedtls_lms_public_t

Struct mbedtls_lms_public_t 

#[repr(C)]
pub struct mbedtls_lms_public_t { pub private_params: mbedtls_lms_parameters_t, pub private_T_1_pub_key: [c_uchar; 32], pub private_have_public_key: c_uchar, }
LMS public context structure.

A LMS public key is the hash output that is the root of the Merkle tree, and the applicable parameter set

The context must be initialized before it is used. A public key must either be imported or generated from a private context.

\dot digraph lms_public_t { UNINITIALIZED -> INIT [label=“init”]; HAVE_PUBLIC_KEY -> INIT [label=“free”]; INIT -> HAVE_PUBLIC_KEY [label=“import_public_key”]; INIT -> HAVE_PUBLIC_KEY [label=“calculate_public_key from private key”]; HAVE_PUBLIC_KEY -> HAVE_PUBLIC_KEY [label=“export_public_key”]; } \enddot

Fields

private_params: mbedtls_lms_parameters_tprivate_T_1_pub_key: [c_uchar; 32]

< The public key, in the form of the Merkle tree root node.

private_have_public_key: c_uchar

< Whether the context contains a public key. Boolean values only.