mbedtls_x509_csr

Struct mbedtls_x509_csr 

#[repr(C)]
pub struct mbedtls_x509_csr {
Show 15 fields pub raw: mbedtls_x509_buf, pub cri: mbedtls_x509_buf, pub version: c_int, pub subject_raw: mbedtls_x509_buf, pub subject: mbedtls_x509_name, pub pk: mbedtls_pk_context, pub key_usage: c_uint, pub ns_cert_type: c_uchar, pub subject_alt_names: mbedtls_x509_sequence, pub private_ext_types: c_int, pub sig_oid: mbedtls_x509_buf, pub private_sig: mbedtls_x509_buf, pub private_sig_md: mbedtls_md_type_t, pub private_sig_pk: mbedtls_pk_type_t, pub private_sig_opts: *mut c_void,
}
Certificate Signing Request (CSR) structure.

Some fields of this structure are publicly readable. Do not modify them except via Mbed TLS library functions: the effect of modifying those fields or the data that those fields point to is unspecified.

Fields

raw: mbedtls_x509_buf

< The raw CSR data (DER).

cri: mbedtls_x509_buf

< The raw CertificateRequestInfo body (DER).

version: c_int

< CSR version (1=v1).

subject_raw: mbedtls_x509_buf

< The raw subject data (DER).

subject: mbedtls_x509_name

< The parsed subject data (named information object).

pk: mbedtls_pk_context

< Container for the public key context.

key_usage: c_uint

< Optional key usage extension value: See the values in x509.h

ns_cert_type: c_uchar

< Optional Netscape certificate type extension value: See the values in x509.h

subject_alt_names: mbedtls_x509_sequence

< Optional list of raw entries of Subject Alternative Names extension. These can be later parsed by mbedtls_x509_parse_subject_alt_name.

private_ext_types: c_int

< Bit string containing detected and parsed extensions

sig_oid: mbedtls_x509_bufprivate_sig: mbedtls_x509_bufprivate_sig_md: mbedtls_md_type_t

< Internal representation of the MD algorithm of the signature algorithm, e.g. MBEDTLS_MD_SHA256

private_sig_pk: mbedtls_pk_type_t

< Internal representation of the Public Key algorithm of the signature algorithm, e.g. MBEDTLS_PK_RSA

private_sig_opts: *mut c_void

< Signature options to be passed to mbedtls_pk_verify_ext(), e.g. for RSASSA-PSS