#[repr(C)]pub struct otNat64AddressMapping {
pub mId: u64,
pub mIp4: otIp4Address,
pub mIp6: otIp6Address,
pub mSrcPortOrId: u16,
pub mTranslatedPortOrId: u16,
pub mRemainingTimeMs: u32,
pub mCounters: otNat64ProtocolCounters,
}Expand description
Represents an address mapping record for NAT64.
@note The counters will be reset for each mapping session even for the same address pair. Applications can use mId
to identify different sessions to calculate the packets correctly.
Fields
mId: u64< The unique id for a mapping session.
mIp4: otIp4Address< The IPv4 address of the mapping.
mIp6: otIp6Address< The IPv6 address of the mapping.
mSrcPortOrId: u16The source port or ICMP ID of the mapping. Used when OPENTHREAD_CONFIG_NAT64_PORT_TRANSLATION_ENABLE is true.
mTranslatedPortOrId: u16The translated port or ICMP ID of the mapping. Used when OPENTHREAD_CONFIG_NAT64_PORT_TRANSLATION_ENABLE is true.
mRemainingTimeMs: u32Remaining time in milliseconds before the entry expires.
The remaining time is relative to the initialization of the otNat64AddressMappingIterator, i.e., when
otNat64InitAddressMappingIterator() was called.
mCounters: otNat64ProtocolCounters< Counters.