rmt_rx_event_callbacks_t

Struct rmt_rx_event_callbacks_t 

#[repr(C)]
pub struct rmt_rx_event_callbacks_t { pub on_recv_done: rmt_rx_done_callback_t, }
@brief Group of RMT RX callbacks @note The callbacks are all running under ISR environment @note When CONFIG_RMT_RX_ISR_CACHE_SAFE is enabled, the callback itself and functions called by it should be placed in IRAM. The variables used in the function should be in the SRAM as well.

Fields

on_recv_done: rmt_rx_done_callback_t

< Event callback, invoked when the RMT channel reception is finished or partial data is received