#[repr(C)]pub struct twai_timing_config_t {
pub clk_src: twai_clock_source_t,
pub quanta_resolution_hz: u32,
pub brp: u32,
pub prop_seg: u8,
pub tseg_1: u8,
pub tseg_2: u8,
pub sjw: u8,
pub ssp_offset: u8,
pub triple_sampling: bool,
}Expand description
@brief TWAI bitrate timing config advanced mode
@note Setting one of quanta_resolution_hz and brp is enough, otherwise, brp is not used.
Fields
clk_src: twai_clock_source_t< Optional, clock source, remain 0 to using TWAI_CLK_SRC_DEFAULT by default
quanta_resolution_hz: u32< The resolution of one timing quanta, in Hz. If setting, brp will be ignored
brp: u32< Bit rate pre-divider, clock_source_freq / brp = quanta_resolution_hz
prop_seg: u8< Prop_seg length, in quanta time
tseg_1: u8< Seg_1 length, in quanta time
tseg_2: u8< Seg_2 length, in quanta time
sjw: u8< Sync jump width, in quanta time
ssp_offset: u8< Secondary sample point offset refet to Sync seg, in quanta time, set 0 to disable ssp
triple_sampling: bool< Deprecated, in favor of ssp_offset