uart_bitrate_res_t

Struct uart_bitrate_res_t 

#[repr(C)]
pub struct uart_bitrate_res_t { pub low_period: u32, pub high_period: u32, pub pos_period: u32, pub neg_period: u32, pub edge_cnt: u32, pub clk_freq_hz: u32, }
@brief Structure to store the measurement results for UART bitrate detection within the measurement period

Formula to calculate the bitrate: If the signal is ideal, bitrate = clk_freq_hz * 2 / (low_period + high_period) If the signal is weak along falling edges, then you may use bitrate = clk_freq_hz * 2 / pos_period If the signal is weak along rising edges, then you may use bitrate = clk_freq_hz * 2 / neg_period

Fields

low_period: u32

< Stores the minimum tick count of a low-level pulse

high_period: u32

< Stores the minimum tick count of a high-level pulse

pos_period: u32

< Stores the minimum tick count between two positive edges

neg_period: u32

< Stores the minimum tick count between two negative edges

edge_cnt: u32

< Stores the count of RX edge changes (10-bit counter, be careful, it could overflow)

clk_freq_hz: u32

< The frequency of the tick being used to count the measurement results, in Hz