#[repr(C)]pub struct wifi_bss_max_idle_config_t {
pub period: u16,
pub protected_keep_alive: bool,
}Expand description
@brief Configuration structure for BSS max idle
Fields
period: u16< Sets BSS Max idle period (1 Unit = 1000TUs OR 1.024 Seconds). If there are no frames for this period from a STA, SoftAP will disassociate due to inactivity. Setting it to 0 disables the feature
protected_keep_alive: bool< Requires clients to use protected keep alive frames for BSS Max Idle period