#[repr(C)]pub struct wifi_nan_followup_params_t {
pub inst_id: u8,
pub peer_inst_id: u8,
pub peer_mac: [u8; 6],
pub svc_info: [c_char; 64],
pub ssi_len: u16,
pub ssi: *mut u8,
}Expand description
@brief NAN Follow-up parameters
Fields
inst_id: u8< Own service instance id
peer_inst_id: u8< Peer’s service instance id
peer_mac: [u8; 6]< Peer’s MAC address
svc_info: [c_char; 64]< To be deprecated in next major release, use ssi instead
ssi_len: u16< Length of service specific info, maximum allowed length - ESP_WIFI_MAX_FUP_SSI_LEN
ssi: *mut u8< Service Specific Info of type wifi_nan_wfa_ssi_t for WFA defined protocols, otherwise proprietary and defined by Applications