#[repr(C)]pub struct wifi_scan_config_t {
pub ssid: *mut u8,
pub bssid: *mut u8,
pub channel: u8,
pub show_hidden: bool,
pub scan_type: wifi_scan_type_t,
pub scan_time: wifi_scan_time_t,
pub home_chan_dwell_time: u8,
pub channel_bitmap: wifi_scan_channel_bitmap_t,
pub coex_background_scan: bool,
}Expand description
@brief Parameters for an SSID scan
Fields
ssid: *mut u8< SSID of AP
bssid: *mut u8< MAC address of AP
channel: u8< Channel, scan the specific channel
< Enable it to scan AP whose SSID is hidden
scan_type: wifi_scan_type_t< Scan type, active or passive
scan_time: wifi_scan_time_t< Scan time per channel
home_chan_dwell_time: u8< Time spent at home channel between scanning consecutive channels.
channel_bitmap: wifi_scan_channel_bitmap_t< Channel bitmap for setting specific channels to be scanned. Please note that the ‘channel’ parameter above needs to be set to 0 to allow scanning by bitmap. Also, note that only allowed channels configured by wifi_country_t can be scanned.
coex_background_scan: bool< Enable it to scan return home channel under coexist