wpa_crypto_funcs_t

Struct wpa_crypto_funcs_t 

#[repr(C)]
pub struct wpa_crypto_funcs_t { pub size: u32, pub version: u32, pub hmac_sha256_vector: esp_hmac_sha256_vector_t, pub pbkdf2_sha1: esp_pbkdf2_sha1_t, pub aes_128_encrypt: esp_aes_128_encrypt_t, pub aes_128_decrypt: esp_aes_128_decrypt_t, pub omac1_aes_128: esp_omac1_aes_128_t, pub ccmp_decrypt: esp_ccmp_decrypt_t, pub ccmp_encrypt: esp_ccmp_encrypt_t, pub aes_gmac: esp_aes_gmac_t, pub sha256_vector: esp_sha256_vector_t, }
@brief The crypto callback function structure used by esp_wifi. The structure can be set as software crypto or the crypto optimized by device’s hardware.

Fields

size: u32

< The crypto callback function structure size

version: u32

< The crypto callback function structure version

hmac_sha256_vector: esp_hmac_sha256_vector_t

< The SHA256 callback function used by esp_wifi

pbkdf2_sha1: esp_pbkdf2_sha1_t

< SHA1-based key derivation function (PBKDF2) callback function for IEEE 802.11

aes_128_encrypt: esp_aes_128_encrypt_t

< The AES 128 encrypt callback function used by esp_wifi

aes_128_decrypt: esp_aes_128_decrypt_t

< The AES 128 decrypt callback function used by esp_wifi

omac1_aes_128: esp_omac1_aes_128_t

< One-Key CBC MAC (OMAC1) hash with AES-128 callback function for MIC computation

ccmp_decrypt: esp_ccmp_decrypt_t

< Decrypt data callback function using CCMP

ccmp_encrypt: esp_ccmp_encrypt_t

< Encrypt data callback function using CCMP

aes_gmac: esp_aes_gmac_t

< One-Key GMAC hash callback function with AES for MIC computation

sha256_vector: esp_sha256_vector_t

< SHA256 hash callback function for data vector