ETSEvent

Type Alias ETSEvent 

pub type ETSEvent = ETSEventTag;

Aliased Type

#[repr(C)]
pub struct ETSEvent { pub sig: u32, pub par: u32, }

Fields

sig: u32

< Event signal, in same task, different Event with different signal

par: u32

< Event parameter, sometimes without usage, then will be set as 0