QueueSetMemberHandle_t

Type Alias QueueSetMemberHandle_t 

pub type QueueSetMemberHandle_t = *mut QueueDefinition;
Queue sets can contain both queues and semaphores, so the QueueSetMemberHandle_t is defined as a type to be used where a parameter or return value can be either an QueueHandle_t or an SemaphoreHandle_t.