httpd_close_func_t

Type Alias httpd_close_func_t 

pub type httpd_close_func_t = Option<unsafe extern "C" fn(hd: httpd_handle_t, sockfd: c_int)>;
@brief Function prototype for closing a session.

@note It’s possible that the socket descriptor is invalid at this point, the function is called for all terminated sessions. Ensure proper handling of return codes.

@param[in] hd server instance @param[in] sockfd session socket file descriptor

Aliased Type

pub enum httpd_close_func_t {
    None,
    Some(unsafe extern "C" fn(*mut c_void, i32)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut c_void, i32))

Some value of type T.