ip4_addr_t

Type Alias ip4_addr_t 

pub type ip4_addr_t = ip4_addr;
ip4_addr_t uses a struct for convenience only, so that the same defines can operate both on ip4_addr_t as well as on ip4_addr_p_t.

Aliased Type

#[repr(C)]
pub struct ip4_addr_t { pub addr: u32, }

Fields

addr: u32