mbedtls_ecdsa_context

Type Alias mbedtls_ecdsa_context 

pub type mbedtls_ecdsa_context = mbedtls_ecp_keypair;
\brief The ECDSA context structure.

\warning Performing multiple operations concurrently on the same ECDSA context is not supported; objects of this type should not be shared between multiple threads.

\note pk_wrap module assumes that “ecdsa_context” is identical to “ecp_keypair” (see for example structure “mbedtls_eckey_info” where ECDSA sign/verify functions are used also for EC key)

Aliased Type

#[repr(C)]
pub struct mbedtls_ecdsa_context { pub private_grp: mbedtls_ecp_group, pub private_d: mbedtls_mpi, pub private_Q: mbedtls_ecp_point, }

Fields

private_grp: mbedtls_ecp_group

< Elliptic curve and base point

private_d: mbedtls_mpi

< our secret value

private_Q: mbedtls_ecp_point

< our public value