mbedtls_ecp_group_id

Type Alias mbedtls_ecp_group_id 

pub type mbedtls_ecp_group_id = c_uint;
Domain-parameter identifiers: curve, subgroup, and generator.

\note Only curves over prime fields are supported.

\warning This library does not support validation of arbitrary domain parameters. Therefore, only standardized domain parameters from trusted sources should be used. See mbedtls_ecp_group_load().