netif_output_fn

Type Alias netif_output_fn 

pub type netif_output_fn = Option<unsafe extern "C" fn(netif: *mut netif, p: *mut pbuf, ipaddr: *const ip4_addr_t) -> err_t>;
Function prototype for netif->output functions. Called by lwIP when a packet shall be sent. For ethernet netif, set this to ‘etharp_output’ and set ‘linkoutput’.

@param netif The netif which shall send a packet @param p The packet to send (p->payload points to IP header) @param ipaddr The IP address to which the packet shall be sent

Aliased Type

pub enum netif_output_fn {
    None,
    Some(unsafe extern "C" fn(*mut netif, *mut pbuf, *const ip4_addr) -> i8),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut netif, *mut pbuf, *const ip4_addr) -> i8)

Some value of type T.