psa_pake_primitive_t

Type Alias psa_pake_primitive_t 

pub type psa_pake_primitive_t = u32;
\brief Encoding of the primitive associated with the PAKE.

For more information see the documentation of the #PSA_PAKE_PRIMITIVE macro.