sdmmc_delay_phase_t

Type Alias sdmmc_delay_phase_t 

pub type sdmmc_delay_phase_t = c_uint;
SD/MMC Host clock timing delay phases

This will only take effect when the host works in

  • SDMMC_FREQ_HIGHSPEED
  • SDMMC_FREQ_52M
  • SDR50
  • DDR50 Driver will print out how long the delay is, in picosecond (ps).