touch_pad_denoise_t

Type Alias touch_pad_denoise_t 

pub type touch_pad_denoise_t = touch_pad_denoise;
Touch sensor denoise configuration

Aliased Type

#[repr(C)]
pub struct touch_pad_denoise_t { pub grade: u32, pub cap_level: u32, }

Fields

grade: u32

<Select denoise range of denoise channel. Determined by measuring the noise amplitude of the denoise channel.

cap_level: u32

<Select internal reference capacitance of denoise channel. Ensure that the denoise readings are closest to the readings of the channel being measured. Use touch_pad_denoise_read_data to get the reading of denoise channel. The equivalent capacitance of the shielded channel can be calculated from the reading of denoise channel.