walker_heap_into_t

Type Alias walker_heap_into_t 

pub type walker_heap_into_t = walker_heap_info;
@brief Structure used to store heap related data passed to the walker callback function

Aliased Type

#[repr(C)]
pub struct walker_heap_into_t { pub start: isize, pub end: isize, }

Fields

start: isize

< Start address of the heap in which the block is located

end: isize

< End address of the heap in which the block is located