pub unsafe extern "C" fn coex_module_disable()Expand description
@brief Disable coex module
@note Calling this function will only disable coex module. @note For ESP32S2, ESP32S3, and ESP32C3, this function has no effect because the coex module clock is controlled by the modem clock.