pub unsafe extern "C" fn coex_module_enable()Expand description
@brief Enable coex module
@note Calling this function will only enable coex module. @note For ESP32S2, ESP32S3, and ESP32C3, this function has no effect because the coex module clock is controlled by the modem clock. On these chips, you must call esp_wifi_init() to enable the modem clock before using external coexistence features.