pub unsafe extern "C" fn esp_efuse_enable_rom_secure_download_mode() -> esp_err_tExpand description
@brief Switch ROM Download Mode to Secure Download mode via eFuse
Permanently enables Secure Download mode. This mode limits the use of ROM Download Mode functions to simple flash read, write and erase operations, plus a command to return a summary of currently enabled security features.
@note If Secure Download mode is already enabled, this function does nothing and returns success.
@note If UART DL mode is completely disabled then Secure Download mode can not be enabled and this API simply returns success.
@return
- ESP_OK If the eFuse was successfully burned, or had already been burned, or UART DL mode is already disabled.
- Other errors If an error occurred while burning ESP_EFUSE_ENABLE_SECURITY_DOWNLOAD.