pub unsafe extern "C" fn esp_http_client_is_persistent_connection(
client: esp_http_client_handle_t,
) -> boolExpand description
@brief Check if persistent connection is supported by the server
@param[in] client The HTTP client handle
@return true if persistent connection is supported, false otherwise