pub unsafe extern "C" fn esp_image_bootloader_offset_set(offset: u32)Expand description
@brief Set the ota bootloader offset
The esp_image_verify functions use the offset to distinguish between application and bootloader verifications. The application must set the OTA bootloader offset before running any verification functions for the OTA bootloader partition.
@param offset ota Bootloader offset