pub unsafe extern "C" fn esp_lcd_panel_set_brightness(
panel: esp_lcd_panel_handle_t,
brightness: c_int,
) -> esp_err_tExpand description
@brief Set the brightness of the display
@param[in] panel LCD panel handle, which is created by other factory API like esp_lcd_new_panel_st7789()
@param[in] brightness Brightness value (range depends on panel implementation, typically 0-255, 0-1023, or 0-100)
@return
- ESP_OK on success
- ESP_ERR_NOT_SUPPORTED if this function is not supported by the panel