pub unsafe extern "C" fn esp_log(
config: esp_log_config_t,
tag: *const c_char,
format: *const c_char,
...
)Expand description
@brief Logs a formatted message using the provided log message configs and a variable argument list.
@param config Configuration and level of the log message. @param tag The tag string used to indicate the component from which to log. It is also used to check whether logging is enabled for that tag (depends on CONFIG_LOG_TAG_LEVEL_IMPL). If NULL then the tag is not printed. @param format The format string for the log message. @param … Optional arguments to be formatted according to the format string.