pub unsafe extern "C" fn esp_log_buffer_char_internal(
tag: *const c_char,
buffer: *const c_void,
buff_len: u16,
level: esp_log_level_t,
)Expand description
@brief This function logs a buffer of characters with 16 characters per line. The buffer should contain only printable characters. The log level determines the severity of the log message.
@note This function does not check the log level against the ESP_LOCAL_LEVEL. The log level comparison should be done in esp_log.h.
@param tag Description tag to identify the log. @param buffer Pointer to the buffer array containing the data to be logged. @param buff_len Length of the buffer in bytes. @param level Log level indicating the severity of the log message.