pub unsafe extern "C" fn esp_log_buffer_hexdump_internal(
tag: *const c_char,
buffer: *const c_void,
buff_len: u16,
log_level: esp_log_level_t,
)Expand description
@brief This function dumps a buffer to the log in a formatted hex dump style, displaying both the memory address and the corresponding hex and ASCII values of the bytes. The log level determines the severity of the log message.
@note This function does not check the log level against the ESP_LOCAL_LEVEL. The log level comparison should be done in esp_log.h. @note It is recommended to use terminals with a width of at least 102 characters to display the log dump properly.
@param tag Description tag to identify the log. @param buffer Pointer to the buffer array containing the data to be logged. @param buff_len Length of the buffer in bytes. @param log_level Log level indicating the severity of the log message.