pub unsafe extern "C" fn esp_log_level_get(
tag: *const c_char,
) -> esp_log_level_tExpand description
@brief Get log level for a given tag, can be used to avoid expensive log statements
If CONFIG_LOG_DYNAMIC_LEVEL_CONTROL is not selected the static (no-op) implementation of log level is used. Changing the log level is not possible, esp_log_level_set does not work. This function returns the default log level.
@param tag Tag of the log to query current level. Must be a zero terminated string. If tag is NULL then the default log level is returned (see esp_log_get_default_level()). @return The current log level for the given tag.