pub unsafe extern "C" fn esp_log_level_set(
tag: *const c_char,
level: esp_log_level_t,
)Expand description
@brief Set log level for given tag
If logging for given component has already been enabled, changes previous setting.
@note Note that this function can not raise log level above the level set using CONFIG_LOG_MAXIMUM_LEVEL setting in menuconfig.
To raise log level above the default one for a given file, define LOG_LOCAL_LEVEL to one of the ESP_LOG_* values, before including esp_log.h in this file.
If CONFIG_LOG_DYNAMIC_LEVEL_CONTROL is not selected the static (no-op) implementation of log level is used. Changing the log level is not possible, esp_log_level_set does not work.
@param tag Tag of the log entries to enable. Must be a non-NULL zero terminated string. Value “*” resets log level for all tags to the given value. If the tag is NULL then a silent return happens. @param level Selects log level to enable. Only logs at this and lower verbosity levels will be shown.