pub unsafe extern "C" fn esp_openthread_rcp_version_set(
version_str: *const c_char,
) -> esp_err_tExpand description
@brief Set the RCP version string.
@note This function should be called before esp_openthread_init. When the RCP version string is not an empty string,
compatibility checks will be performed during the initialization of the ESP OpenThread radio spinel.
The esp_openthread_compatibility_error_callback will be triggered if the desired RCP version does not match
the actual version running on the RCP. If needed, a NULL parameter can be passed to clear the version string.
@param[in] version_str The pointer to RCP version string.
@return - ESP_OK on success - ESP_FAIL if fail to set RCP version string