pub unsafe extern "C" fn esp_ota_invalidate_inactive_ota_data_slot() -> esp_err_tExpand description
@brief Invalidate the OTA data slot associated with the last boot application partition.
This function erases the OTA data slot corresponding to the last boot application partition, making the partition invalid for booting in future. The application partition itself is not erased, preserving its contents.
@return
- ESP_OK: Successfully invalidated the OTA data slot.
- ESP_FAIL: Failed to invalidate the OTA data slot (e.g., invalid parameters, no OTA data partition, or other errors).
- Other error codes from esp_partition_erase_range.