pub unsafe extern "C" fn esp_sleep_get_wakeup_cause() -> esp_sleep_wakeup_cause_tExpand description
@brief Get the wakeup source which caused wakeup from sleep
@note !!! This API will only return one wakeup source. If multiple wakeup sources wake up at the same time, the wakeup source information may be lost.
@return cause of wake up from last sleep (deep sleep or light sleep)