pub unsafe extern "C" fn esp_tls_server_session_continue_async(
tls: *mut esp_tls_t,
) -> c_intExpand description
@brief Asynchronous continue of esp_tls_server_session_init
This function should be called in a loop by the user until it returns 0. If this functions returns something other than 0, ESP_TLS_ERR_SSL_WANT_READ or ESP_TLS_ERR_SSL_WANT_WRITE, the esp-tls context must not be used and should be freed using esp_tls_conn_destroy();
@param[in] tls pointer to esp_tls_t
@return - 0 if successful - <0 in case of error - ESP_TLS_ERR_SSL_WANT_READ/ESP_TLS_ERR_SSL_WANT_WRITE if the handshake is incomplete and waiting for data to be available for reading.