pub unsafe extern "C" fn esp_transport_ssl_set_ciphersuites_list(
t: esp_transport_handle_t,
ciphersuites_list: *const c_int,
)Expand description
@brief Set the SSL cipher suites list
@note This function stores a pointer to the data rather than making a copy.
Therefore, the data must remain valid until the connection is cleaned up.
The ciphersuites_list is a pointer to a zero-terminated array of IANA identifiers of TLS cipher suites.
You can verify the validity of the list using the esp_tls_get_ciphersuites_list() API.
@param t SSL transport @param[in] ciphersuites_list A pointer to a zero-terminated array of IANA identifiers of TLS cipher suites