pub unsafe extern "C" fn esp_wifi_internal_get_mac_clock_time() -> u32Expand description
@brief Get the time information from the MAC clock. The time is precise only if modem sleep or light sleep is not enabled.
@return 32-bit time value, unit: microsecond. This time is only 32 bits, which means it will overflow and reset to 0 after approximately 71 minutes. Therefore, when using it, the time difference between two consecutive readings should not be too long.