pub unsafe extern "C" fn esprv_int_setup_mgmt_cb(fptr: *mut c_void)Expand description
@brief Setup the callback function which executes the interrupt configuration APIs as TEE service calls
@note This function should be called right after landing in the REE application, before any system initialization
@param fptr Pointer to the function