pub unsafe extern "C" fn mbedtls_asn1_write_ia5_string(
p: *mut *mut c_uchar,
start: *const c_uchar,
text: *const c_char,
text_len: usize,
) -> c_intExpand description
\brief Write a string in ASN.1 format using the IA5String string encoding tag (#MBEDTLS_ASN1_IA5_STRING).
\note This function works backwards in data buffer.
\param p The reference to the current position pointer. \param start The start of the buffer, for bounds-checking. \param text The string to write. \param text_len The length of \p text in bytes (which might be strictly larger than the number of characters).
\return The number of bytes written to \p p on success. \return A negative error code on failure.