pub unsafe extern "C" fn mbedtls_asn1_write_raw_buffer(
p: *mut *mut c_uchar,
start: *const c_uchar,
buf: *const c_uchar,
size: usize,
) -> c_intExpand description
\brief Write raw buffer data.
\note This function works backwards in data buffer.
\param p The reference to the current position pointer. \param start The start of the buffer, for bounds-checking. \param buf The data buffer to write. \param size The length of the data buffer.
\return The number of bytes written to \p p on success. \return A negative \c MBEDTLS_ERR_ASN1_XXX error code on failure.