pub unsafe extern "C" fn mbedtls_dhm_get_len(
ctx: *const mbedtls_dhm_context,
) -> usizeExpand description
\brief This function returns the size of the prime modulus in bytes.
\param ctx The DHM context to query.
\return The size of the prime modulus in bytes, i.e. the number n such that 2^(8*(n-1)) <= P < 2^(8*n).