pub unsafe extern "C" fn mbedtls_hmac_drbg_seed_buf(
ctx: *mut mbedtls_hmac_drbg_context,
md_info: *const mbedtls_md_info_t,
data: *const c_uchar,
data_len: usize,
) -> c_intExpand description
\param ctx HMAC_DRBG context to be initialised. \param md_info MD algorithm to use for HMAC_DRBG. \param data Concatenation of the initial entropy string and the additional data. \param data_len Length of \p data in bytes.
\return \c 0 if successful. or \return #MBEDTLS_ERR_MD_BAD_INPUT_DATA if \p md_info is invalid. \return #MBEDTLS_ERR_MD_ALLOC_FAILED if there was not enough memory to allocate context data.