pub unsafe extern "C" fn mbedtls_hmac_drbg_set_entropy_len(
ctx: *mut mbedtls_hmac_drbg_context,
len: usize,
)Expand description
\brief This function sets the amount of entropy grabbed on each seed or reseed.
See the documentation of mbedtls_hmac_drbg_seed() for the default value.
\param ctx The HMAC_DRBG context. \param len The amount of entropy to grab, in bytes.