pub unsafe extern "C" fn mbedtls_pkcs7_signed_hash_verify(
pkcs7: *mut mbedtls_pkcs7,
cert: *const mbedtls_x509_crt,
hash: *const c_uchar,
hashlen: usize,
) -> c_intExpand description
\brief Verification of PKCS #7 signature against a caller-supplied certificate.
For each signer in the PKCS structure, this function
validates a signature over the supplied hash, using the
supplied certificate and the same digest algorithm as
specified by the signer. Verification succeeds if any
signature is good.
This function does not use the certificates held within the
PKCS #7 structure itself, and does not check that the
certificate is signed by a trusted certification authority.\param pkcs7 PKCS #7 structure containing signature. \param cert Certificate containing key to verify signature. \param hash Hash of the plain data on which signature has to be verified. \param hashlen Length of the hash.
\note This function is different from mbedtls_pkcs7_signed_data_verify() in that it is directly passed the hash of the data.
\return 0 if the signature verifies, or a negative error code on failure.