pub unsafe extern "C" fn mbedtls_version_check_feature(
feature: *const c_char,
) -> c_intExpand description
\brief Check if support for a feature was compiled into this Mbed TLS binary. This allows you to see at runtime if the library was for instance compiled with or without Multi-threading support.
\note only checks against defines in the sections “System support”, “Mbed TLS modules” and “Mbed TLS feature support” in mbedtls_config.h
\param feature The string for the define to check (e.g. “MBEDTLS_AES_C”)
\return 0 if the feature is present, -1 if the feature is not present and -2 if support for feature checking as a whole was not compiled in.