pub unsafe extern "C" fn multi_heap_find_containing_block(
heap: multi_heap_handle_t,
ptr: *mut c_void,
) -> *mut c_voidExpand description
@brief Function walking through a given heap and returning the pointer to the allocated block containing the pointer passed as parameter.
@note The heap parameter must be valid and the pointer parameter must belong to a block of allocated memory. The app will crash with an assertion failure if at least one of the parameter is invalid.
@param heap The heap to walk through @param ptr The pointer to find the allocated block of @return Pointer to the allocated block containing the pointer ptr