pub unsafe extern "C" fn otSteeringDataContainsJoinerId(
aSteeringData: *const otSteeringData,
aJoinerId: *const otExtAddress,
) -> boolExpand description
Checks if the Steering Data contains a Joiner ID.
@param[in] aSteeringData The Steering Data to check. @param[in] aJoinerId The Joiner ID.
@retval TRUE If the Steering Data contains the Joiner ID. @retval FALSE If the Steering Data does not contain the Joiner ID.