pub unsafe extern "C" fn uart_get_tx_buffer_free_size(
uart_num: uart_port_t,
size: *mut usize,
) -> esp_err_tExpand description
@brief UART get TX ring buffer free space size for the next data to be enqueued
It returns the tight conservative bound for NOSPLIT ring buffer overall enqueueable payload across up to two chunks.
@param uart_num UART port number, the max port number is (UART_NUM_MAX -1). @param size Pointer of size_t to accept the free space size
@return - ESP_OK Success - ESP_ERR_INVALID_ARG Parameter error