#[repr(C)]pub struct gpio_io_config_t {
pub fun_sel: u32,
pub sig_out: u32,
pub drv: gpio_drive_cap_t,
pub pu: bool,
pub pd: bool,
pub ie: bool,
pub oe: bool,
pub oe_ctrl_by_periph: bool,
pub oe_inv: bool,
pub od: bool,
pub slp_sel: bool,
}Expand description
@brief Structure that contains the configuration of an IO
Fields
fun_sel: u32< Value of IOMUX function selection
sig_out: u32< Index of the outputting peripheral signal
drv: gpio_drive_cap_t< Value of drive strength
pu: bool< Status of pull-up enabled or not
pd: bool< Status of pull-down enabled or not
ie: bool< Status of input enabled or not
oe: bool< Status of output enabled or not
oe_ctrl_by_periph: bool< True if use output enable signal from peripheral, otherwise False
oe_inv: bool< Whether the output enable signal is inversed or not
od: bool< Status of open-drain enabled or not
slp_sel: bool< Status of pin sleep mode enabled or not