#[repr(C)]pub struct mbedtls_ctr_drbg_context {
pub private_counter: [c_uchar; 16],
pub private_reseed_counter: c_int,
pub private_prediction_resistance: c_int,
pub private_entropy_len: usize,
pub private_reseed_interval: c_int,
pub private_aes_ctx: mbedtls_aes_context,
pub private_f_entropy: Option<unsafe extern "C" fn(arg1: *mut c_void, arg2: *mut c_uchar, arg3: usize) -> c_int>,
pub private_p_entropy: *mut c_void,
}Expand description
\brief The CTR_DRBG context structure.
Fields
private_counter: [c_uchar; 16]< The counter (V).
private_reseed_counter: c_int< The reseed counter. This is the number of requests that have been made since the last (re)seeding, minus one. Before the initial seeding, this field contains the amount of entropy in bytes to use as a nonce for the initial seeding, or -1 if no nonce length has been explicitly set (see mbedtls_ctr_drbg_set_nonce_len()).
private_prediction_resistance: c_int< This determines whether prediction resistance is enabled, that is whether to systematically reseed before each random generation.
private_entropy_len: usize< The amount of entropy grabbed on each seed or reseed operation, in bytes.
private_reseed_interval: c_int< The reseed interval. This is the maximum number of requests that can be made between reseedings.
private_aes_ctx: mbedtls_aes_context< The AES context.
private_f_entropy: Option<unsafe extern "C" fn(arg1: *mut c_void, arg2: *mut c_uchar, arg3: usize) -> c_int>private_p_entropy: *mut c_void< The context for the entropy function.