#[repr(C)]pub struct mbedtls_nist_kw_context {
pub private_cipher_ctx: mbedtls_cipher_context_t,
}Expand description
\brief The key wrapping context-type definition. The key wrapping context is passed to the APIs called.
\note The definition of this type may change in future library versions. Don’t make any assumptions on this context!
Fields
private_cipher_ctx: mbedtls_cipher_context_t< The cipher context used.