#[repr(C)]pub struct wifi_scan_threshold_t {
pub rssi: i8,
pub authmode: wifi_auth_mode_t,
pub rssi_5g_adjustment: u8,
}Expand description
@brief Structure describing parameters for a Wi-Fi fast scan
Fields
rssi: i8< The minimum rssi to accept in the fast scan mode. Defaults to -127 if set to >= 0
authmode: wifi_auth_mode_t< The weakest auth mode to accept in the fast scan mode Note: In case this value is not set and password is set as per WPA2 standards(password len >= 8), it will be defaulted to WPA2 and device won’t connect to deprecated WEP/WPA networks. Please set auth mode threshold as WIFI_AUTH_WEP/WIFI_AUTH_WPA_PSK to connect to WEP/WPA networks
rssi_5g_adjustment: u8< The RSSI value of the 5G AP is within the rssi_5g_adjustment range compared to the 2G AP, the 5G AP will be given priority for connection.